# GemAct

GemAct is a comprehensive **actuarial package**, based on the collective risk theory framework, that offers a comprehensive set of tools for **non-life** (re)insurance **pricing**, stochastic **claims reserving**, **risk aggregation** and extends the set of probability distributions already available in Python.

The variety of available functionalities makes GemAct modeling very flexible and provides actuarial scientists and practitioners with a powerful tool that fits into the expanding community of **Python** programming language.

Please visit our [website](https://gem-analytics.github.io/gemact/) to see our documentation and tutorial.

